@@ -1,3 +1,5 @@
+from ._version import version as __version__  # noqa: F401
+
 """Database utilities"""
 import logging
 from typing import Any, Dict, Optional, Union
@@ -5,12 +7,11 @@ from urllib.parse import urlsplit
 
 from sqlalchemy import create_engine
 from sqlalchemy.ext.declarative import declarative_base, declared_attr
-from sqlalchemy.orm import sessionmaker
-from sqlalchemy.orm.session import Session
+from sqlalchemy.orm import Session, sessionmaker
 from sqlalchemy.pool import NullPool
 from sshtunnel import SSHTunnelForwarder
 
-from hdx.database.postgres import wait_for_postgres
+from hdx.database.postgresql import wait_for_postgresql
 
 logger = logging.getLogger(__name__)
 
@@ -33,7 +34,7 @@ class Database:
         port (Union[int, str, None]): Database port
         username (Optional[str]): Username to log into database
         password (Optional[str]): Password to log into database
-        driver (str): Database driver. Defaults to 'postgres'.
+        driver (str): Database driver. Defaults to "postgresql".
         **kwargs: See below
         ssh_host (str): SSH host (the server to connect to)
         ssh_port (int): SSH port. Defaults to 22.
@@ -51,7 +52,7 @@ class Database:
         port: Union[int, str, None] = None,
         username: Optional[str] = None,
         password: Optional[str] = None,
-        driver: str = "postgres",
+        driver: str = "postgresql",
         **kwargs: Any,
     ) -> None:
         if port is not None:
@@ -66,15 +67,17 @@ class Database:
             else:
                 ssh_port = 22
             self.server = SSHTunnelForwarder(
-                (ssh_host, ssh_port), remote_bind_address=(host, port), **kwargs
+                (ssh_host, ssh_port),
+                remote_bind_address=(host, port),
+                **kwargs,
             )
             self.server.start()
             host = self.server.local_bind_host
             port = self.server.local_bind_port
         else:
             self.server = None
-        if driver == "postgres":
-            wait_for_postgres(database, host, port, username, password)
+        if driver == "postgresql":
+            wait_for_postgresql(database, host, port, username, password)
         db_url = self.get_sqlalchemy_url(
             database, host, port, username, password, driver=driver
         )
@@ -97,7 +100,7 @@ class Database:
             db_url (str): SQLAlchemy url
 
         Returns:
-            sqlalchemy.orm.session.Session: SQLAlchemy session
+            sqlalchemy.orm.Session: SQLAlchemy session
         """
         engine = create_engine(db_url, poolclass=NullPool, echo=False)
         Session = sessionmaker(bind=engine)
@@ -131,7 +134,7 @@ class Database:
         port: Union[int, str, None] = None,
         username: Optional[str] = None,
         password: Optional[str] = None,
-        driver: str = "postgres",
+        driver: str = "postgresql",
     ) -> str:
         """Gets SQLAlchemy url from database connection parameters
 
@@ -141,7 +144,7 @@ class Database:
             port (Union[int, str, None]): Database port
             username (Optional[str]): Username to log into database
             password (Optional[str]): Password to log into database
-            driver (str): Database driver. Defaults to 'postgres'.
+            driver (str): Database driver. Defaults to "postgresql".
 
         Returns:
             db_url (str): SQLAlchemy url
